nxp-pac

Crates

git

Versions

mimxrt1011

Flavors

Gpr10

Struct Gpr10 

#[repr(transparent)]
pub struct Gpr10(pub u32);
GPR10 General Purpose Register

Tuple Fields

0: u32

Implementations

Source

impl Gpr10

pub const fn niden(&self) -> Niden

Arm non-secure (non-invasive) debug enable

pub const fn set_niden(&mut self, val: Niden)

Arm non-secure (non-invasive) debug enable

pub const fn dbg_en(&self) -> DbgEn

Arm invasive debug enable

pub const fn set_dbg_en(&mut self, val: DbgEn)

Arm invasive debug enable

pub const fn sec_err_resp(&self) -> SecErrResp

Security error response enable for all security gaskets (on both AHB and AXI buses)

pub const fn set_sec_err_resp(&mut self, val: SecErrResp)

Security error response enable for all security gaskets (on both AHB and AXI buses)

pub const fn dcpkey_ocotp_or_keymux(&self) -> DcpkeyOcotpOrKeymux

DCP Key selection bit.

pub const fn set_dcpkey_ocotp_or_keymux(&mut self, val: DcpkeyOcotpOrKeymux)

DCP Key selection bit.

pub const fn ocram_tz_en(&self) -> OcramTzEn

OCRAM TrustZone (TZ) enable.

pub const fn set_ocram_tz_en(&mut self, val: OcramTzEn)

OCRAM TrustZone (TZ) enable.

pub const fn ocram_tz_addr(&self) -> u8

OCRAM TrustZone (TZ) start address

pub const fn set_ocram_tz_addr(&mut self, val: u8)

OCRAM TrustZone (TZ) start address

pub const fn lock_niden(&self) -> LockNiden

Lock NIDEN field for changes

pub const fn set_lock_niden(&mut self, val: LockNiden)

Lock NIDEN field for changes

pub const fn lock_dbg_en(&self) -> LockDbgEn

Lock DBG_EN field for changes

pub const fn set_lock_dbg_en(&mut self, val: LockDbgEn)

Lock DBG_EN field for changes

pub const fn lock_sec_err_resp(&self) -> LockSecErrResp

Lock SEC_ERR_RESP field for changes

pub const fn set_lock_sec_err_resp(&mut self, val: LockSecErrResp)

Lock SEC_ERR_RESP field for changes

pub const fn lock_dcpkey_ocotp_or_keymux(&self) -> LockDcpkeyOcotpOrKeymux

Lock DCP Key OCOTP/Key MUX selection bit

pub const fn set_lock_dcpkey_ocotp_or_keymux( &mut self, val: LockDcpkeyOcotpOrKeymux, )

Lock DCP Key OCOTP/Key MUX selection bit

pub const fn lock_ocram_tz_en(&self) -> LockOcramTzEn

Lock OCRAM_TZ_EN field for changes

pub const fn set_lock_ocram_tz_en(&mut self, val: LockOcramTzEn)

Lock OCRAM_TZ_EN field for changes

pub const fn lock_ocram_tz_addr(&self) -> LockOcramTzAddr

Lock OCRAM_TZ_ADDR field for changes

pub const fn set_lock_ocram_tz_addr(&mut self, val: LockOcramTzAddr)

Lock OCRAM_TZ_ADDR field for changes