nxp-pac

Crates

git

Versions

mimxrt1011

Flavors

Gpr2

Struct Gpr2 

#[repr(transparent)]
pub struct Gpr2(pub u32);
GPR2 General Purpose Register

Tuple Fields

0: u32

Implementations

Source

impl Gpr2

pub const fn axbs_p_m0_high_priority(&self) -> AxbsPM0HighPriority

AXBS_P M0 master has higher priority.Do not set both M1 and M0 to high priority.

pub const fn set_axbs_p_m0_high_priority(&mut self, val: AxbsPM0HighPriority)

AXBS_P M0 master has higher priority.Do not set both M1 and M0 to high priority.

pub const fn axbs_p_m1_high_priority(&self) -> AxbsPM1HighPriority

AXBS_P M1 master has higher priority.Do not set both M1 and M0 to high priority.

pub const fn set_axbs_p_m1_high_priority(&mut self, val: AxbsPM1HighPriority)

AXBS_P M1 master has higher priority.Do not set both M1 and M0 to high priority.

pub const fn axbs_p_force_round_robin(&self) -> AxbsPForceRoundRobin

Force Round Robin in AXBS_P. This bit can override master M0 M1 high priority configuration.

pub const fn set_axbs_p_force_round_robin(&mut self, val: AxbsPForceRoundRobin)

Force Round Robin in AXBS_P. This bit can override master M0 M1 high priority configuration.

pub const fn l2_mem_en_powersaving(&self) -> L2MemEnPowersaving

Enable power saving features on L2 memory

pub const fn set_l2_mem_en_powersaving(&mut self, val: L2MemEnPowersaving)

Enable power saving features on L2 memory

pub const fn ram_auto_clk_gating_en(&self) -> RamAutoClkGatingEn

Automatically gate off RAM clock when RAM is not accessed.

pub const fn set_ram_auto_clk_gating_en(&mut self, val: RamAutoClkGatingEn)

Automatically gate off RAM clock when RAM is not accessed.

pub const fn l2_mem_deepsleep(&self) -> L2MemDeepsleep

This bit controls how memory (OCRAM) enters Deep Sleep mode (shutdown periphery power, but maintain memory contents, outputs of memory are pulled low

pub const fn set_l2_mem_deepsleep(&mut self, val: L2MemDeepsleep)

This bit controls how memory (OCRAM) enters Deep Sleep mode (shutdown periphery power, but maintain memory contents, outputs of memory are pulled low

pub const fn mqs_clk_div(&self) -> MqsClkDiv

Divider ratio control for mclk from hmclk

pub const fn set_mqs_clk_div(&mut self, val: MqsClkDiv)

Divider ratio control for mclk from hmclk

pub const fn mqs_sw_rst(&self) -> MqsSwRst

MQS software reset

pub const fn set_mqs_sw_rst(&mut self, val: MqsSwRst)

MQS software reset

pub const fn mqs_en(&self) -> MqsEn

MQS enable.

pub const fn set_mqs_en(&mut self, val: MqsEn)

MQS enable.

pub const fn mqs_oversample(&self) -> MqsOversample

Medium Quality Sound (MQS) Oversample

pub const fn set_mqs_oversample(&mut self, val: MqsOversample)

Medium Quality Sound (MQS) Oversample