#[repr(transparent)]pub struct Gpr2(pub u32);Expand description
GPR2 General Purpose Register
Tuple Fields
0: u32Implementations
Sourceimpl Gpr2
impl Gpr2
Sourcepub const fn axbs_p_m0_high_priority(&self) -> AxbsPM0HighPriority
pub const fn axbs_p_m0_high_priority(&self) -> AxbsPM0HighPriority
AXBS_P M0 master has higher priority.Do not set both M1 and M0 to high priority.
Sourcepub const fn set_axbs_p_m0_high_priority(&mut self, val: AxbsPM0HighPriority)
pub const fn set_axbs_p_m0_high_priority(&mut self, val: AxbsPM0HighPriority)
AXBS_P M0 master has higher priority.Do not set both M1 and M0 to high priority.
Sourcepub const fn axbs_p_m1_high_priority(&self) -> AxbsPM1HighPriority
pub const fn axbs_p_m1_high_priority(&self) -> AxbsPM1HighPriority
AXBS_P M1 master has higher priority.Do not set both M1 and M0 to high priority.
Sourcepub const fn set_axbs_p_m1_high_priority(&mut self, val: AxbsPM1HighPriority)
pub const fn set_axbs_p_m1_high_priority(&mut self, val: AxbsPM1HighPriority)
AXBS_P M1 master has higher priority.Do not set both M1 and M0 to high priority.
Sourcepub const fn axbs_p_force_round_robin(&self) -> AxbsPForceRoundRobin
pub const fn axbs_p_force_round_robin(&self) -> AxbsPForceRoundRobin
Force Round Robin in AXBS_P. This bit can override master M0 M1 high priority configuration.
Sourcepub const fn set_axbs_p_force_round_robin(&mut self, val: AxbsPForceRoundRobin)
pub const fn set_axbs_p_force_round_robin(&mut self, val: AxbsPForceRoundRobin)
Force Round Robin in AXBS_P. This bit can override master M0 M1 high priority configuration.
Sourcepub const fn l2_mem_en_powersaving(&self) -> L2MemEnPowersaving
pub const fn l2_mem_en_powersaving(&self) -> L2MemEnPowersaving
Enable power saving features on L2 memory
Sourcepub const fn set_l2_mem_en_powersaving(&mut self, val: L2MemEnPowersaving)
pub const fn set_l2_mem_en_powersaving(&mut self, val: L2MemEnPowersaving)
Enable power saving features on L2 memory
Sourcepub const fn ram_auto_clk_gating_en(&self) -> RamAutoClkGatingEn
pub const fn ram_auto_clk_gating_en(&self) -> RamAutoClkGatingEn
Automatically gate off RAM clock when RAM is not accessed.
Sourcepub const fn set_ram_auto_clk_gating_en(&mut self, val: RamAutoClkGatingEn)
pub const fn set_ram_auto_clk_gating_en(&mut self, val: RamAutoClkGatingEn)
Automatically gate off RAM clock when RAM is not accessed.
Sourcepub const fn l2_mem_deepsleep(&self) -> L2MemDeepsleep
pub const fn l2_mem_deepsleep(&self) -> L2MemDeepsleep
This bit controls how memory (OCRAM) enters Deep Sleep mode (shutdown periphery power, but maintain memory contents, outputs of memory are pulled low
Sourcepub const fn set_l2_mem_deepsleep(&mut self, val: L2MemDeepsleep)
pub const fn set_l2_mem_deepsleep(&mut self, val: L2MemDeepsleep)
This bit controls how memory (OCRAM) enters Deep Sleep mode (shutdown periphery power, but maintain memory contents, outputs of memory are pulled low
Sourcepub const fn mqs_clk_div(&self) -> MqsClkDiv
pub const fn mqs_clk_div(&self) -> MqsClkDiv
Divider ratio control for mclk from hmclk
Sourcepub const fn set_mqs_clk_div(&mut self, val: MqsClkDiv)
pub const fn set_mqs_clk_div(&mut self, val: MqsClkDiv)
Divider ratio control for mclk from hmclk
Sourcepub const fn mqs_sw_rst(&self) -> MqsSwRst
pub const fn mqs_sw_rst(&self) -> MqsSwRst
MQS software reset
Sourcepub const fn set_mqs_sw_rst(&mut self, val: MqsSwRst)
pub const fn set_mqs_sw_rst(&mut self, val: MqsSwRst)
MQS software reset
Sourcepub const fn set_mqs_en(&mut self, val: MqsEn)
pub const fn set_mqs_en(&mut self, val: MqsEn)
MQS enable.
Sourcepub const fn mqs_oversample(&self) -> MqsOversample
pub const fn mqs_oversample(&self) -> MqsOversample
Medium Quality Sound (MQS) Oversample
Sourcepub const fn set_mqs_oversample(&mut self, val: MqsOversample)
pub const fn set_mqs_oversample(&mut self, val: MqsOversample)
Medium Quality Sound (MQS) Oversample